@@ -88,7 +88,9 @@ impl Drawing {
     where
         T: Into<Shape>,
     {
-        self.shapes.push(shape.into());
+        let mut s: Shape = shape.into();
+        s.update_pos(s.pos.pos + self.position);
+        self.shapes.push(s);
         self
     }
 
